package com.ruoyi.powerdistribution.controller;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.math.BigDecimal;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson.JSON;
import com.opencsv.CSVReader;
import com.opencsv.exceptions.CsvValidationException;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.powerdistribution.domain.PdmVehicleDrivingRecord;
import com.ruoyi.powerdistribution.service.IPdmVehicleDrivingRecordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 施工车辆行驶记录Controller
 * 
 * @author ruoyi
 * @date 2025-01-21
 */
@RestController
@RequestMapping("/powerdistribution/vehicleDrivingRecord")
public class PdmVehicleDrivingRecordController extends BaseController
{
    @Autowired
    private IPdmVehicleDrivingRecordService pdmVehicleDrivingRecordService;

    /**
     * 查询施工车辆行驶记录列表
     */
    @GetMapping("/list")
    public TableDataInfo list(PdmVehicleDrivingRecord pdmVehicleDrivingRecord)
    {
        startPage();
        List<PdmVehicleDrivingRecord> list = pdmVehicleDrivingRecordService.selectPdmVehicleDrivingRecordList(pdmVehicleDrivingRecord);
        return getDataTable(list);
    }

    /**
     * 导出施工车辆行驶记录列表
     */
    @Log(title = "施工车辆行驶记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PdmVehicleDrivingRecord pdmVehicleDrivingRecord)
    {
        List<PdmVehicleDrivingRecord> list = pdmVehicleDrivingRecordService.selectPdmVehicleDrivingRecordList(pdmVehicleDrivingRecord);
        ExcelUtil<PdmVehicleDrivingRecord> util = new ExcelUtil<PdmVehicleDrivingRecord>(PdmVehicleDrivingRecord.class);
        util.exportExcel(response, list, "施工车辆行驶记录数据");
    }

    /**
     * 获取施工车辆行驶记录详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(pdmVehicleDrivingRecordService.selectPdmVehicleDrivingRecordById(id));
    }

    /**
     * 新增施工车辆行驶记录
     */
    @Log(title = "施工车辆行驶记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PdmVehicleDrivingRecord pdmVehicleDrivingRecord)
    {
        return toAjax(pdmVehicleDrivingRecordService.insertPdmVehicleDrivingRecord(pdmVehicleDrivingRecord));
    }

    /**
     * 修改施工车辆行驶记录
     */
    @Log(title = "施工车辆行驶记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PdmVehicleDrivingRecord pdmVehicleDrivingRecord)
    {
        return toAjax(pdmVehicleDrivingRecordService.updatePdmVehicleDrivingRecord(pdmVehicleDrivingRecord));
    }

    /**
     * 删除施工车辆行驶记录
     */
    @Log(title = "施工车辆行驶记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(pdmVehicleDrivingRecordService.deletePdmVehicleDrivingRecordByIds(ids));
    }
    @PostMapping("/import")
    public void importExcel(HttpServletRequest request, MultipartFile file)throws IOException, CsvValidationException {
             CSVReader csvReader = new CSVReader(new InputStreamReader(file.getInputStream(), StandardCharsets.UTF_8));
            String[] nextLine;
            int i=0;
            List<PdmVehicleDrivingRecord> dataList=new ArrayList<>();
            while ((nextLine = csvReader.readNext()) != null) {
                if(i>0) {
                    // 处理每一行数据，nextLine是一个字符串数组，包含当前行的每个字段
                    PdmVehicleDrivingRecord vehicleDrivingRecord = new PdmVehicleDrivingRecord();
                    vehicleDrivingRecord.setVehicleGroup(nextLine[0]);
                    vehicleDrivingRecord.setEquipNm(nextLine[1]);
                    vehicleDrivingRecord.setEquipNo(nextLine[2]);
                    vehicleDrivingRecord.setVehicleNo(nextLine[3]);
                    vehicleDrivingRecord.setStartTm( DateUtils.covertStrToLocalTime(nextLine[4]));
                    vehicleDrivingRecord.setEndTm( DateUtils.covertStrToLocalTime(nextLine[5]));
                    vehicleDrivingRecord.setMileage(new BigDecimal(nextLine[6]));
                    dataList.add(vehicleDrivingRecord);
                }
                i++;
            }
            System.out.println(JSON.toJSON(dataList));
        pdmVehicleDrivingRecordService.batchAdd(dataList);
    }
}
