package com.ruoyi.powerdistribution.service;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmWorkPlan;
import com.ruoyi.powerdistribution.domain.dto.PdmWorkPlanDTO;
import com.ruoyi.powerdistribution.domain.vo.WorkNumByCompanyStatistics;
import com.ruoyi.powerdistribution.domain.vo.WorkRiskStatistics;

/**
 * 作业计划Service接口
 *
 * @author ruoyi
 * @date 2024-12-01
 */
public interface IPdmWorkPlanService
{
    /**
     * 查询作业计划
     *
     * @param id 作业计划主键
     * @return 作业计划
     */
    public PdmWorkPlan selectPdmWorkPlanById(Long id);

    /**
     * 查询作业计划列表
     *
     * @param pdmWorkPlan 作业计划
     * @return 作业计划集合
     */
    public List<PdmWorkPlan> selectPdmWorkPlanList(PdmWorkPlanDTO pdmWorkPlan);

    /**
     * 新增作业计划
     *
     * @param pdmWorkPlan 作业计划
     * @return 结果
     */
    public int insertPdmWorkPlan(PdmWorkPlan pdmWorkPlan);

    /**
     * 修改作业计划
     *
     * @param pdmWorkPlan 作业计划
     * @return 结果
     */
    public int updatePdmWorkPlan(PdmWorkPlan pdmWorkPlan);

    /**
     * 批量删除作业计划
     *
     * @param ids 需要删除的作业计划主键集合
     * @return 结果
     */
    public int deletePdmWorkPlanByIds(Long[] ids);

    /**
     * 删除作业计划信息
     *
     * @param id 作业计划主键
     * @return 结果
     */
    public int deletePdmWorkPlanById(Long id);

    /**
     * 查询风险汇总
     * @param date
     * @return
     */
    List<WorkRiskStatistics> getWorkRiskStatistics(String date);

    /**
     * 根据作业单位分类查询作业数量汇总
     * @param workNumByCompany
     * @return
     */
    List<WorkNumByCompanyStatistics> getWorkNumByCompanyStatistics(WorkNumByCompanyStatistics workNumByCompany);

    /**
     * 作业数据分析 (异常，风险)
     */
    void workDataCompute();

    /**
     * 查询车辆作业信息
     * @param vchicleNo
     * @return
     */
    List<PdmWorkPlan> selectWorkPlanByVchicleNo(String vchicleNo);
}
