package com.ruoyi.powerdistribution.service.impl;

import java.util.*;

import com.alibaba.fastjson.JSON;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.bean.BeanUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.ruoyi.powerdistribution.domain.PdmConstructor;
import com.ruoyi.powerdistribution.domain.excel.ConstructTeam;
import com.ruoyi.powerdistribution.domain.vo.PdmConstructTeamVo;
import com.ruoyi.powerdistribution.mapper.PdmConstructorMapper;
import com.ruoyi.powerdistribution.mapper.PdmVehicleAlarmMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.powerdistribution.mapper.PdmConstructTeamMapper;
import com.ruoyi.powerdistribution.domain.PdmConstructTeam;
import com.ruoyi.powerdistribution.service.IPdmConstructTeamService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 配网工程队伍施工小组信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-01-20
 */
@Service
public class PdmConstructTeamServiceImpl implements IPdmConstructTeamService 
{
    @Autowired
    private PdmConstructTeamMapper pdmConstructTeamMapper;

    @Autowired
    private PdmConstructorMapper pdmConstructorMapper;
    @Autowired
    private PdmVehicleAlarmMapper pdmVehicleAlarmMapper;

    /**
     * 查询配网工程队伍施工小组信息
     * 
     * @param id 配网工程队伍施工小组信息主键
     * @return 配网工程队伍施工小组信息
     */
    @Override
    public PdmConstructTeam selectPdmConstructTeamById(Long id)
    {
        return pdmConstructTeamMapper.selectPdmConstructTeamById(id);
    }

    /**
     * 查询配网工程队伍施工小组信息列表
     * 
     * @param pdmConstructTeam 配网工程队伍施工小组信息
     * @return 配网工程队伍施工小组信息
     */
    @Override
    public List<PdmConstructTeam> selectPdmConstructTeamList(PdmConstructTeam pdmConstructTeam)
    {
        return pdmConstructTeamMapper.selectPdmConstructTeamList(pdmConstructTeam);
    }

    /**
     * 新增配网工程队伍施工小组信息
     * 
     * @param pdmConstructTeam 配网工程队伍施工小组信息
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertPdmConstructTeam(PdmConstructTeamVo pdmConstructTeam)
    {
        String teamNo= IdUtils.fastSimpleUUID();
        pdmConstructTeam.setCreateTime(DateUtils.getNowDate());
        pdmConstructTeam.setCreateBy(SecurityUtils.getUsername());
        pdmConstructTeam.setTeamNo(teamNo);
        for(PdmConstructor constructor:pdmConstructTeam.getConstructorList()){
            constructor.setTeamNo(teamNo);
            constructor.setCreateTime(DateUtils.getNowDate());
            constructor.setCreateBy(SecurityUtils.getUsername());
            pdmConstructorMapper.insertPdmConstructor(constructor);
        }

        int i= pdmConstructTeamMapper.insertPdmConstructTeam(pdmConstructTeam);
        pdmVehicleAlarmMapper.insertVehicleAlar();
         return i;
    }

    /**
     * 修改配网工程队伍施工小组信息
     * 
     * @param pdmConstructTeam 配网工程队伍施工小组信息
     * @return 结果
     */
    @Override
    public int updatePdmConstructTeam(PdmConstructTeamVo pdmConstructTeam)
    {
        pdmConstructTeam.setUpdateTime(DateUtils.getNowDate());
        pdmConstructTeam.setUpdateBy(SecurityUtils.getUsername());
        pdmConstructorMapper.deletePdmConstructorByTeamId(pdmConstructTeam.getId());
        for(PdmConstructor constructor:pdmConstructTeam.getConstructorList()){
            //if(pdmConstructorMapper.updatePdmConstructor(constructor)<1){
                constructor.setTeamNo(pdmConstructTeam.getTeamNo());
                pdmConstructorMapper.insertPdmConstructor(constructor);
           // }
        }
        int i= pdmConstructTeamMapper.updatePdmConstructTeam(pdmConstructTeam);
        pdmVehicleAlarmMapper.insertVehicleAlar();
        return i;
    }

    /**
     * 批量删除配网工程队伍施工小组信息
     * 
     * @param ids 需要删除的配网工程队伍施工小组信息主键
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deletePdmConstructTeamByIds(Long[] ids)
    {
        for(Long id:ids){
            PdmConstructTeam constructTeam= pdmConstructTeamMapper.selectPdmConstructTeamById(id);
            for(String carNo:  constructTeam.getConstrucCarNumber()){
                pdmVehicleAlarmMapper.deletePdmVehicleAlarmByVehicleNo(carNo);
            }
        }
        pdmConstructorMapper.deletePdmConstructorByTeamIds(ids);
        return pdmConstructTeamMapper.deletePdmConstructTeamByIds(ids);
    }

    /**
     * 删除配网工程队伍施工小组信息信息
     * 
     * @param id 配网工程队伍施工小组信息主键
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deletePdmConstructTeamById(Long id)
    {
        PdmConstructTeam constructTeam= pdmConstructTeamMapper.selectPdmConstructTeamById(id);
        for(String carNo:  constructTeam.getConstrucCarNumber()){
            pdmVehicleAlarmMapper.deletePdmVehicleAlarmByVehicleNo(carNo);
        }
        pdmConstructorMapper.deletePdmConstructorByTeamId(id);
        return pdmConstructTeamMapper.deletePdmConstructTeamById(id);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void importExcel(List<ConstructTeam> constructTeamList) {
        Map<String,PdmConstructTeamVo> data=new HashMap<>();
        for (ConstructTeam constructTeam : constructTeamList) {
            String key=constructTeam.getCountyOrgNm()+","+constructTeam.getTeamNm()+","+constructTeam.getLegalPerson()+","+constructTeam.getLegalContactPhone()
                    +","+constructTeam.getTeamLeader()+","+constructTeam.getTeamLeaderPhone();
            if(data.containsKey(key)){
                PdmConstructor constructor=new PdmConstructor();
                BeanUtils.copyProperties(constructTeam,constructor);
                PdmConstructTeamVo constructTeamVo=data.get(key);
                constructTeamVo.getConstructorList().add(constructor);
            }else{

                PdmConstructTeamVo constructTeamVo=new PdmConstructTeamVo();
                BeanUtils.copyProperties(constructTeam,constructTeamVo);
                if(StringUtils.isNotEmpty(constructTeam.getCarNumber())){
                    constructTeam.setCarNumber(constructTeam.getCarNumber().replaceAll(" ","").replaceAll("、",",")
                            .replaceAll("\n",",").replaceAll("\r",",").replaceAll("，",",").toUpperCase()
                    );
                    constructTeamVo.setConstrucCarNumber(Arrays.asList(constructTeam.getCarNumber().split(",")));
                }
                PdmConstructor constructor=new PdmConstructor();
                BeanUtils.copyProperties(constructTeam,constructor);
                List<PdmConstructor> constructorList= new ArrayList<>();
                constructorList.add(constructor);
                constructTeamVo.setConstructorList(constructorList);
                data.put(key,constructTeamVo);
            }
        }
        System.out.println("解析数据:"+ JSON.toJSON(data.values()));
        pdmConstructTeamMapper.clean();
        pdmConstructorMapper.clean();
        List<PdmConstructor> allConstructor=new ArrayList<>();
        List<PdmConstructTeamVo> constructTeamVos=new ArrayList<>(data.values());
        data.values().forEach(dmConstructTeamVo->{
            String teamNo= IdUtils.fastSimpleUUID();
            dmConstructTeamVo.setCreateTime(DateUtils.getNowDate());
            dmConstructTeamVo.setCreateBy(SecurityUtils.getUsername());
            dmConstructTeamVo.setTeamNo(teamNo);
            for(PdmConstructor constructor:dmConstructTeamVo.getConstructorList()){
                constructor.setTeamNo(teamNo);
                constructor.setCreateTime(DateUtils.getNowDate());
                constructor.setCreateBy(SecurityUtils.getUsername());
                allConstructor.add(constructor);
            }
        });
        pdmConstructTeamMapper.batchAdd(constructTeamVos);
        pdmConstructorMapper.batchAdd(allConstructor);
        pdmVehicleAlarmMapper.insertVehicleAlar();
    }
}
